@@ -196,11 +196,12 @@ string ConnectionToBrowser::PrepareHeaderForServer( bool ScannerOff, bool UsePar
         header += "X-Forwarded-For: ";
         header += GetIP();
         header += "\r\n";
+
+        header += "Via: 1.0 HAVP";
+        header += via;
+        header += "\r\n";
     }
 
-    header += "Via: 1.0 HAVP";
-    header += via;
-    header += "\r\n";
 
     return header;
 }
@@ -332,7 +333,7 @@ int ConnectionToBrowser::GetHostAndPortOfHostLine( string &HostLineT )
     {
         Host = HostwithPort.substr( 0, PositionPort );
 
-        if ( Host.length() > 67 )
+        if ( Host.length() > 256 )
         {
             return -210;
         }
@@ -384,24 +385,26 @@ int ConnectionToBrowser::GetHostAndPortOfRequest( string &RequestT, string::size
                 {
                     Host = HostwithPort.substr( 0, Begin );
 
-                    if (Host.length() > 67)
+                    if (Host.length() > 256)
                     {
                         return -210;
                     }
 
                     string PortString = HostwithPort.substr( Begin );
 
-                    //Normally only 443 and 563 are allowed ports
-                    if ( PortString != ":443" && PortString != ":563" )
-                    {
-                        return -211;
-                    }
-
                     if ( sscanf(PortString.c_str(), ":%d", &Port) == 1 )
                     {
                         Request = HostwithPort;
 
-                        return 0;
+                        //If you want more control, edit or use Squid in front
+                        if ( Port >= 80 && Port <= 65535 )
+                        {
+                            return 0;
+                        }
+                        else
+                        {
+                            return -211;
+                        }
                     }
                 }
             }
@@ -561,7 +564,7 @@ int ConnectionToBrowser::GetHostAndPortOfRequest( string &RequestT, string::size
     }
 
     //Sanity check - TODO: Config variable for allowed ports?
-    if ( Host.length() > 73 )
+    if ( Host.length() > 256 )
     {
         return -210;
     }
@@ -651,7 +654,7 @@ bool ConnectionToBrowser::RewriteHost()
 
 void ConnectionToBrowser::ClearVars()
 {
-    RequestProtocol = RequestType = Request = Host = IP = FtpUser = FtpPass = UserAgent = "";
+    RequestProtocol = RequestType = Request = Host = IP = FtpUser = FtpPass = UserAgent = CompleteRequest = "";
     Port = ContentLength = -1;
     IsKeepAlive = ProxyConnection = IsStreamAgent = false;
 }
