@@ -40,8 +40,8 @@ string FtpUser;
 string FtpPass;
 string UserAgent;
 long long ContentLength;
-bool KeepAlive;
-bool StreamAgent;
+bool IsKeepAlive;
+bool IsStreamAgent;
 vector<string> Methods;
 vector<string> StreamUA;
 
@@ -66,8 +66,8 @@ const string GetCompleteRequest();
 const string GetRequestProtocol();
 const string GetRequestType();
 const string GetUserAgent();
-bool KeepItAlive();
-bool StreamingAgent();
+bool IsItKeepAlive();
+bool IsItStreamAgent();
 long long GetContentLength();
 int GetPort();
 void ClearVars();
